# A supervisor config file generator

[![PyPi Version](http://img.shields.io/pypi/v/supervisor-conf-generator.svg)](https://pypi.python.org/pypi/supervisor-conf-generator/)

[>> Read the docs <<](https://neoctobers.readthedocs.io/en/latest/repo/py_supervisor_conf_generator.html)

